@@ -18,7 +18,7 @@ else {
     require MRO::Compat;
 }
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 our $CAN_HAZ_XS =
     !$ENV{PERL_MOOS_XS_DISABLE} &&
@@ -970,7 +970,8 @@ keywords.
 =head1 Whence Moos
 
 I(ngy) created Moos during L<Pegex> development. Pegex uses a clone of Moos
-called L<Pegex::Base>.
+called L<Pegex::Base>. (L<Moos> ships with a commandline utility called
+C<remoos> that does this cloning.)
 
 Pegex is a parser framework and needs to be fast. While looking into speed
 issues I noted that accessor calling was the biggest hit. I tried all the
@@ -979,8 +980,8 @@ various Mo* solutions and L<Mouse> was the fastest.
 I was happy until I remembered that Mouse uses XS, and for various reasons
 this broke my toolchain (TestML, Module::Install, etc).
 
-I tried to inline L<Moo> into one file but failed, and ended up with this.
-I've shared Pegex::Base as L<Moos> in case any other projects want it.
+So I made a single module/file Moose clone and it worked out well. I've shared
+Pegex::Base as L<Moos> in case any other projects want it.
 
 Later on, Toby Inkster added a bunch of low-cost but very handy features from
 Moose.
